@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: semigroupoids
 version: 5.0.1
-id: semigroupoids-5.0.1-ab1721c6c7a72801e6cd851407a313ad
-key: semig_8j4erjbZ8FD5XHq1lfTNCS
+id: semigroupoids-5.0.1-8eb2d2c8f0f0def85cbb7c35538a003a
+key: semig_IFBU77hSbUD7lvpAJeOqOt
 license: BSD3
 copyright: Copyright (C) 2011-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -59,17 +59,17 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/semigroupoids-5.0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/semigroupoids-5.0.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/semigroupoids-5.0.1
-hs-libraries: HSsemigroupoids-5.0.1-8j4erjbZ8FD5XHq1lfTNCS
+hs-libraries: HSsemigroupoids-5.0.1-IFBU77hSbUD7lvpAJeOqOt
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base-orphans-0.5.4-e40139ef3f9e9946a3f68f9fef66a420
-    bifunctors-5.3-b6e9a28a0175204e65003b150c0bbe80
-    comonad-5-3b2e208311908bc5a9db1ceb26126917
+    bifunctors-5.3-bc094c1e88d075fab4936b454b930127
+    comonad-5-9b3bac8b2740903020c84a0c2eebf7b2
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
-    distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
-    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
-    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
+    contravariant-1.4-1b3716257293d15c38698a7852cba3ac
+    distributive-0.5.0.2-77d85d8c453ea57cf04087f9320d2bf7
+    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
+    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
 haddock-interfaces: /usr/share/doc/haskell-semigroupoids/html/semigroupoids.haddock
